@@ -164,7 +164,9 @@ function createUser($userMgmt, $input, $authData) {
     // Optional resource limits
     $resources = $input['resources'] ?? [];
     
-    $result = $userMgmt->create_new_user($input['username'], $input['password']);
+    // Skip default resources if custom resources are provided
+    $skip_defaults = !empty($resources);
+    $result = $userMgmt->create_new_user($input['username'], $input['password'], $skip_defaults);
     
     if ($result['status'] === '0') {
         $userData = [
@@ -173,33 +175,30 @@ function createUser($userMgmt, $input, $authData) {
             'created_at' => date('c')
         ];
         
-        // Set resource limits if provided, otherwise ensure defaults are set
-        if (!empty($resources)) {
-            $resourceResult = setUserResources($input['username'], $resources);
-            if ($resourceResult) {
-                $userData['resources'] = $resources;
-            } else {
-                error_log("Failed to set custom resources for user: " . $input['username']);
-            }
+        // Set resource limits - either custom or defaults
+        $resourcesToSet = $resources;
+        if (empty($resourcesToSet)) {
+            // Use default resources if none provided
+            $resourcesToSet = [
+                'cpu_cores' => 0.5,
+                'memory_mb' => 512,
+                'disk_mb' => 1000,
+                'email_accounts' => 0,
+                'email_storage_mb' => 1000
+            ];
+            error_log("Using default resources for user: " . $input['username']);
         } else {
-            // Ensure default resources exist (create_new_user should have set these, but verify)
-            $existingResources = getUserResources($input['username']);
-            if (!$existingResources) {
-                // If no resources exist, set basic defaults
-                $defaultResources = [
-                    'cpu_cores' => 0.5,
-                    'memory_mb' => 512,
-                    'disk_mb' => 1000,
-                    'email_accounts' => 0,
-                    'email_storage_mb' => 1000
-                ];
-                $resourceResult = setUserResources($input['username'], $defaultResources);
-                if ($resourceResult) {
-                    $userData['resources'] = $defaultResources;
-                }
-            } else {
-                $userData['resources'] = $existingResources;
-            }
+            error_log("Using WHMCS resources for user: " . $input['username'] . " - " . json_encode($resourcesToSet));
+        }
+        
+        $resourceResult = setUserResources($input['username'], $resourcesToSet);
+        if ($resourceResult) {
+            $userData['resources'] = $resourcesToSet;
+            error_log("Successfully set resources for user: " . $input['username']);
+        } else {
+            error_log("Failed to set resources for user: " . $input['username']);
+            // If resource setting failed, return error
+            api_response(false, null, 'User created but failed to set resource limits', 500);
         }
         
         // Create domain if provided
@@ -350,63 +349,31 @@ function setUserResources($username, $resources) {
         $db = $MySQLMgmt->getMySQLConnection();
         $db->exec("USE whp");
         
-        // Check if user already has resource limits
-        $stmt = $db->prepare("SELECT id FROM client_allowances WHERE username = ?");
-        $stmt->execute([$username]);
-        $exists = $stmt->fetch();
+        // Use the proper updateClientAllowances method for validation and quota sync
+        $result = $MySQLMgmt->updateClientAllowances(
+            $username,
+            $resources['cpu_cores'] ?? 0.5,
+            $resources['memory_mb'] ?? 512,
+            null, // max_domains not needed for this call
+            $resources['disk_mb'] ?? 1000,
+            $resources['email_accounts'] ?? 0,
+            $resources['email_storage_mb'] ?? 1000
+        );
         
-        if ($exists) {
-            // Update existing limits
-            $fields = [];
-            $values = [];
+        // Sync filesystem quota if disk space was provided
+        if (isset($resources['disk_mb']) && $result['status'] === '0') {
+            $disk_quota_mb = intval($resources['disk_mb']);
+            $quota_cmd = '/root/whp/scripts/quota-helper.sh set ' . escapeshellarg($username) . ' ' . $disk_quota_mb . ' 2>&1';
+            $quota_output = shell_exec($quota_cmd);
+            $quota_exit_code = 0;
+            exec('/root/whp/scripts/quota-helper.sh set ' . escapeshellarg($username) . ' ' . $disk_quota_mb, $quota_exec_output, $quota_exit_code);
             
-            // Map API field names to database column names (only WHP-tracked resources)
-            $fieldMapping = [
-                'cpu_cores' => 'max_cpu_allowance',
-                'memory_mb' => 'max_memory_allowance',
-                'disk_mb' => 'max_disk_space',
-                'email_accounts' => 'max_email_accounts',
-                'email_storage_mb' => 'max_email_storage_mb'
-            ];
-            
-            foreach ($fieldMapping as $apiField => $dbColumn) {
-                if (isset($resources[$apiField])) {
-                    $fields[] = "$dbColumn = ?";
-                    $values[] = $resources[$apiField];
-                }
+            if ($quota_exit_code !== 0) {
+                error_log("Failed to update filesystem quota for {$username} to {$disk_quota_mb}MB (exit code: $quota_exit_code): " . trim($quota_output));
             }
-            
-            if (!empty($fields)) {
-                $values[] = $username;
-                $sql = "UPDATE client_allowances SET " . implode(', ', $fields) . " WHERE username = ?";
-                $stmt = $db->prepare($sql);
-                return $stmt->execute($values);
-            }
-        } else {
-            // Insert new limits
-            $stmt = $db->prepare("
-                INSERT INTO client_allowances (username, max_cpu_allowance, max_memory_allowance, max_disk_space, 
-                                             max_domains, max_sites, max_email_accounts, max_email_storage_mb,
-                                             max_databases, api_enabled, api_rate_limit)
-                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
-            ");
-            
-            return $stmt->execute([
-                $username,
-                $resources['cpu_cores'] ?? 0.5,
-                $resources['memory_mb'] ?? 512,
-                $resources['disk_mb'] ?? 1000,
-                $resources['domains'] ?? 1,
-                $resources['sites'] ?? 1,
-                $resources['email_accounts'] ?? 0,
-                $resources['email_storage_mb'] ?? 1000,
-                $resources['databases'] ?? 1,
-                $resources['api_enabled'] ?? false,
-                $resources['api_rate_limit'] ?? 100
-            ]);
         }
         
-        return false;
+        return $result['status'] === '0';
         
     } catch (Exception $e) {
         error_log("Error setting user resources: " . $e->getMessage());
