@@ -392,7 +392,7 @@ class usermgmt {
         }
     }
 
-    public function create_new_user( $username, $password ) {
+    public function create_new_user( $username, $password, $skip_default_resources = false ) {
         // Check if user exists
         $id = shell_exec("/usr/bin/id -u $username");
         if ( is_numeric( $id ) ) {
@@ -468,15 +468,17 @@ class usermgmt {
             error_log("Failed to create MySQL user for {$username}: " . $mysql_result['msg']);
         }
         
-        // Create default resource allowances in database
-        $allowances_result = $MySQLMgmt->updateClientAllowances($username, 0.5, 512, null, 1000, 0);
-        if ($allowances_result['status'] !== '0') {
-            error_log("Failed to create default allowances for {$username}: " . $allowances_result['msg']);
+        // Create default resource allowances in database (unless skipped)
+        if (!$skip_default_resources) {
+            $allowances_result = $MySQLMgmt->updateClientAllowances($username, 0.5, 512, null, 1000, 0);
+            if ($allowances_result['status'] !== '0') {
+                error_log("Failed to create default allowances for {$username}: " . $allowances_result['msg']);
+            }
+            
+            // Set filesystem quota for the new user
+            $this->setUserQuota($username, 1000); // Default 1GB quota
         }
         
-        // Set filesystem quota for the new user
-        $this->setUserQuota($username, 1000); // Default 1GB quota
-        
         // Set up FTP access for the new user
         // Note: With PAM authentication, system users automatically get FTP access
         // No additional database setup required for FTP with PAM
